@@ -1,4 +1,4 @@
-g.readtemp_movisens = function(datafile, desiredtz = "", from = c(), to = c()) {
+g.readtemp_movisens = function(datafile, desiredtz = "", from = c(), to = c(), interpolationType=1) {
     temperature = unisensR::readUnisensSignalEntry(datafile, "temp.bin")
     temperature = as.data.frame(temperature)
     origin = unisensR::readUnisensStartTime(datafile)
@@ -15,7 +15,7 @@ g.readtemp_movisens = function(datafile, desiredtz = "", from = c(), to = c()) {
     timeRes = as.vector(timeRes[1:nr])
     tempRes = matrix(0,nrow = nr, ncol = ncol(rawTemp), dimnames = list(NULL,colnames(rawTemp)))
     rawLast = nrow(rawTemp)
-    tempRes = resample(rawTemp, rawTime, timeRes, rawLast) # this is now the resampled temp data
+    tempRes = resample(rawTemp, rawTime, timeRes, rawLast, type=interpolationType) # this is now the resampled temp data
     if(length(from) > 0 & length(to) > 0) {
        temperature = tempRes[from:to]
     } else {
