@@ -1,14 +1,21 @@
-identify_levels = function(ts,
-                           TRLi,TRMi,TRVi,
-                           boutdur.mvpa,boutcriter.mvpa,
-                           boutdur.lig,boutcriter.lig,
-                           boutdur.in,boutcriter.in,
-                           ws3,bout.metric) {
+identify_levels = function(ts, TRLi, TRMi, TRVi, ws3, params_phyact = c(), ...) {
+  #get input variables
+  input = list(...)
+  expectedArgs = c("ts", "TRLi", "TRMi", "TRVi", "ws3", "params_phyact")
+  if (any(names(input) %in% expectedArgs == FALSE) |
+      any(!unlist(lapply(expectedArgs, FUN = exists)))) {
+    # Extract and check parameters if user provides more arguments than just the parameter arguments
+    # So, inside GGIR this will not be used, but it is used when identify_level is used on its own
+    # as if it was still the old identify_level function
+    params = extract_params(params_phyact = params_phyact,
+                            input = input) # load default parameters
+    params_phyact = params$params_phyact
+  }
   
   #=======================================================
   # LABEL INSENTITY LEVELS
-  LEVELS = rep(0,length(ts$time))
-  OLEVELS = rep(0,length(ts$time)) #to capture moderate and vigorous seperately
+  LEVELS = rep(0, length(ts$time))
+  OLEVELS = rep(0, length(ts$time)) #to capture moderate and vigorous seperately
   LEVELS[ts$sibdetection == 1 & ts$diur == 1] = 0 #Sleep during the Sleep Period Time Window
   LEVELS[ts$sibdetection == 0 & ts$diur == 1] = 1 #Wakefullness during Sleep Period Time Window
   # activity during the night
@@ -35,68 +42,71 @@ identify_levels = function(ts,
   # MVPA BOUTS
   LN = length(ts$time)
   
-  boutduration = boutdur.mvpa * (60/ws3) 
+  boutduration = params_phyact[["boutdur.mvpa"]] * (60 / ws3) 
   NBL = length(boutduration) #number of bout lengths
   CL = 9 #current level
-  refe = rep(0,LN)
+  refe = rep(0, LN)
   bc.mvpa = c()
   for (BL in 1:NBL) { # needs to be flexible to varibale number of bout lengths
-    rr1 = rep(0,LN)
+    rr1 = rep(0, LN)
     p = which(ts$ACC >= TRMi & refe == 0 & ts$diur == 0); rr1[p] = 1
-    out1 = g.getbout(x=rr1,boutduration=boutduration[BL],boutcriter=boutcriter.mvpa,
-                     closedbout=FALSE,bout.metric=bout.metric,ws3=ws3)
+    out1 = g.getbout(x = rr1, boutduration = boutduration[BL], boutcriter = params_phyact[["boutcriter.mvpa"]],
+                     closedbout = FALSE, bout.metric = params_phyact[["bout.metric"]], ws3 = ws3)
     LEVELS[ts$diur == 0 & out1$x == 1] = CL
     bc.mvpa = rbind(bc.mvpa,out1$boutcount)
     refe = refe + out1$x
     if (BL == 1) {
-      Lnames = c(Lnames,paste0("day_MVPA_bts_",boutdur.mvpa[BL]))
+      Lnames = c(Lnames,paste0("day_MVPA_bts_", params_phyact[["boutdur.mvpa"]][BL]))
     } else {
-      Lnames = c(Lnames,paste0("day_MVPA_bts_",boutdur.mvpa[BL],"_",boutdur.mvpa[BL-1]))
+      Lnames = c(Lnames,paste0("day_MVPA_bts_", params_phyact[["boutdur.mvpa"]][BL], "_",
+                               params_phyact[["boutdur.mvpa"]][BL - 1]))
     }
     CL = CL + 1
   }
   #-------------------------------------
   # INACTIVITY BOUTS
   LN = length(ts$time)
-  boutduration = boutdur.in * (60/ws3)
+  boutduration = params_phyact[["boutdur.in"]] * (60/ws3)
   NBL = length(boutduration) #number of bout lengths
   bc.in = c()
   for (BL in 1:NBL) {
     rr1 = rep(0, LN)
     p = which(ts$ACC < TRLi & refe == 0 & ts$diur == 0); rr1[p] = 1
-    out1 = g.getbout(x=rr1, boutduration=boutduration[BL], boutcriter=boutcriter.in,
-                     closedbout=FALSE, bout.metric=bout.metric, ws3=ws3)
+    out1 = g.getbout(x = rr1, boutduration = boutduration[BL], boutcriter = params_phyact[["boutcriter.in"]],
+                     closedbout = FALSE, bout.metric = params_phyact[["bout.metric"]], ws3 = ws3)
     LEVELS[ts$diur == 0 & out1$x == 1] = CL
     bc.in = rbind(bc.in, out1$boutcount)
     refe = refe + out1$x
     if (BL == 1) {
-      Lnames = c(Lnames,paste0("day_IN_bts_", boutdur.in[BL]))
+      Lnames = c(Lnames,paste0("day_IN_bts_", params_phyact[["boutdur.in"]][BL]))
     } else {
-      Lnames = c(Lnames,paste0("day_IN_bts_", boutdur.in[BL], "_", boutdur.in[BL-1]))
+      Lnames = c(Lnames,paste0("day_IN_bts_", params_phyact[["boutdur.in"]][BL], "_",
+                               params_phyact[["boutdur.in"]][BL - 1]))
     }
     CL = CL + 1
   }
   #-------------------------------------
   # LIGHT BOUTS
   LN = length(ts$time)
-  boutduration = boutdur.lig * (60/ws3)
+  boutduration = params_phyact[["boutdur.lig"]] * (60 / ws3)
   NBL = length(boutduration) #number of bout lengths
   bc.lig = c()
   for (BL in 1:NBL) {
-    rr1 = rep(0,LN)
-    p = which(ts$ACC >= TRLi & refe ==0 & ts$ACC < TRMi & ts$diur == 0); rr1[p] = 1
-    out1 = g.getbout(x=rr1,boutduration=boutduration[BL],boutcriter=boutcriter.lig,
-                     closedbout=FALSE,bout.metric=bout.metric,ws3=ws3)                    
+    rr1 = rep(0, LN)
+    p = which(ts$ACC >= TRLi & refe == 0 & ts$ACC < TRMi & ts$diur == 0); rr1[p] = 1
+    out1 = g.getbout(x = rr1, boutduration = boutduration[BL], boutcriter = params_phyact[["boutcriter.lig"]],
+                     closedbout = FALSE, bout.metric = params_phyact[["bout.metric"]], ws3 = ws3)                    
     LEVELS[ts$diur == 0 & out1$x == 1] = CL
     bc.lig = rbind(bc.lig,out1$boutcount)
     refe = refe + out1$x
     if (BL == 1) {
-      Lnames = c(Lnames,paste0("day_LIG_bts_",boutdur.lig[BL]))
+      Lnames = c(Lnames,paste0("day_LIG_bts_",params_phyact[["boutdur.lig"]][BL]))
     } else {
-      Lnames = c(Lnames,paste0("day_LIG_bts_",boutdur.lig[BL],"_",boutdur.lig[BL-1]))
+      Lnames = c(Lnames,paste0("day_LIG_bts_", params_phyact[["boutdur.lig"]][BL],
+                               "_", params_phyact[["boutdur.lig"]][BL - 1]))
     }
     CL = CL + 1
   }
-  invisible(list(LEVELS=LEVELS, OLEVELS=OLEVELS, Lnames=Lnames, 
-                 bc.mvpa=bc.mvpa, bc.lig =bc.lig, bc.in=bc.in, ts=ts))
+  invisible(list(LEVELS = LEVELS, OLEVELS = OLEVELS, Lnames = Lnames, 
+                 bc.mvpa = bc.mvpa, bc.lig = bc.lig, bc.in = bc.in, ts = ts))
 }
\ No newline at end of file
